@@ -1,9 +1,9 @@
 package Archive::Any::Tar;
-$Archive::Any::Tar::VERSION = '0.0942';
+$Archive::Any::Tar::VERSION = '0.0943';
 use strict;
 
 require Archive::Any;
-@ISA = qw(Archive::Any);
+use base 'Archive::Any';
 
 use Archive::Tar;
 use Cwd;
@@ -65,7 +65,7 @@ Archive::Any::Tar - Archive::Any wrapper around Archive::Tar
 
 =head1 VERSION
 
-version 0.0942
+version 0.0943
 
 =head1 SYNOPSIS
 
@@ -101,7 +101,7 @@ Olaf Alders (current maintainer)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Olaf Alders.
+This software is copyright (c) 2016 by Olaf Alders.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
